type18

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 29, 2025 License: GPL-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package type18 implements SMBIOS Type 18 - 32-Bit Memory Error Information Per DSP0134 SMBIOS Reference Specification 3.9.0

Index

Constants

const StructureType uint8 = 18

StructureType is the SMBIOS structure type for 32-Bit Memory Error Information

Variables

This section is empty.

Functions

This section is empty.

Types

type ErrorGranularity

type ErrorGranularity uint8

ErrorGranularity identifies the granularity of the error

const (
	GranularityOther       ErrorGranularity = 0x01
	GranularityUnknown     ErrorGranularity = 0x02
	GranularityDeviceLevel ErrorGranularity = 0x03
	GranularityPartition   ErrorGranularity = 0x04
)

func (ErrorGranularity) String

func (e ErrorGranularity) String() string

type ErrorOperation

type ErrorOperation uint8

ErrorOperation identifies the operation that caused the error

const (
	OperationOther   ErrorOperation = 0x01
	OperationUnknown ErrorOperation = 0x02
	OperationRead    ErrorOperation = 0x03
	OperationWrite   ErrorOperation = 0x04
	OperationPartial ErrorOperation = 0x05
)

func (ErrorOperation) String

func (e ErrorOperation) String() string

type ErrorType

type ErrorType uint8

ErrorType identifies the type of memory error

const (
	ErrorTypeOther              ErrorType = 0x01
	ErrorTypeUnknown            ErrorType = 0x02
	ErrorTypeOK                 ErrorType = 0x03
	ErrorTypeBadRead            ErrorType = 0x04
	ErrorTypeParity             ErrorType = 0x05
	ErrorTypeSingleBit          ErrorType = 0x06
	ErrorTypeDoubleBit          ErrorType = 0x07
	ErrorTypeMultiBit           ErrorType = 0x08
	ErrorTypeNibble             ErrorType = 0x09
	ErrorTypeChecksum           ErrorType = 0x0A
	ErrorTypeCRC                ErrorType = 0x0B
	ErrorTypeCorrectedSingleBit ErrorType = 0x0C
	ErrorTypeCorrected          ErrorType = 0x0D
	ErrorTypeUncorrectable      ErrorType = 0x0E
)

func (ErrorType) String

func (e ErrorType) String() string

type MemoryError32

type MemoryError32 struct {
	Header                  gosmbios.Header
	ErrorType               ErrorType
	ErrorGranularity        ErrorGranularity
	ErrorOperation          ErrorOperation
	VendorSyndrome          uint32
	MemoryArrayErrorAddress uint32
	DeviceErrorAddress      uint32
	ErrorResolution         uint32
}

MemoryError32 represents Type 18 - 32-Bit Memory Error Information

func Get

func Get(sm *gosmbios.SMBIOS) (*MemoryError32, error)

Get retrieves the first 32-Bit Memory Error Information from SMBIOS data

func GetAll

func GetAll(sm *gosmbios.SMBIOS) ([]*MemoryError32, error)

GetAll retrieves all 32-Bit Memory Error Information structures from SMBIOS data

func Parse

func Parse(s *gosmbios.Structure) (*MemoryError32, error)

Parse parses a 32-Bit Memory Error Information structure from raw SMBIOS data

func (*MemoryError32) IsAddressUnknown

func (m *MemoryError32) IsAddressUnknown() bool

IsAddressUnknown returns true if the memory array error address is unknown

func (*MemoryError32) IsDeviceAddressUnknown

func (m *MemoryError32) IsDeviceAddressUnknown() bool

IsDeviceAddressUnknown returns true if the device error address is unknown

func (*MemoryError32) IsResolutionUnknown

func (m *MemoryError32) IsResolutionUnknown() bool

IsResolutionUnknown returns true if the error resolution is unknown

Jump to