type19

package
v1.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 29, 2025 License: GPL-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package type19 implements SMBIOS Type 19 - Memory Array Mapped Address Per DSP0134 SMBIOS Reference Specification 3.9.0

Index

Constants

const StructureType uint8 = 19

StructureType is the SMBIOS structure type for Memory Array Mapped Address

Variables

This section is empty.

Functions

This section is empty.

Types

type MemoryArrayMappedAddress

type MemoryArrayMappedAddress struct {
	Header                  gosmbios.Header
	StartingAddress         uint32 // In KB
	EndingAddress           uint32 // In KB
	MemoryArrayHandle       uint16
	PartitionWidth          uint8
	ExtendedStartingAddress uint64 // In bytes (SMBIOS 2.7+)
	ExtendedEndingAddress   uint64 // In bytes (SMBIOS 2.7+)
}

MemoryArrayMappedAddress represents Type 19 - Memory Array Mapped Address

func Get

Get retrieves the first Memory Array Mapped Address from SMBIOS data

func GetAll

GetAll retrieves all Memory Array Mapped Address structures from SMBIOS data

func Parse

Parse parses a Memory Array Mapped Address structure from raw SMBIOS data

func (*MemoryArrayMappedAddress) GetEndingAddressBytes

func (m *MemoryArrayMappedAddress) GetEndingAddressBytes() uint64

GetEndingAddressBytes returns the ending address in bytes

func (*MemoryArrayMappedAddress) GetSizeBytes

func (m *MemoryArrayMappedAddress) GetSizeBytes() uint64

GetSizeBytes returns the size of the mapped region in bytes

func (*MemoryArrayMappedAddress) GetSizeString

func (m *MemoryArrayMappedAddress) GetSizeString() string

GetSizeString returns a human-readable size string

func (*MemoryArrayMappedAddress) GetStartingAddressBytes

func (m *MemoryArrayMappedAddress) GetStartingAddressBytes() uint64

GetStartingAddressBytes returns the starting address in bytes

Jump to